A plug that ensures a "session_token" UUID exists in the session.
The session token is used by the multi-account linking flow. Adding this plug ensures a token exists before the user reaches any multi-account routes, avoiding fallback token generation in the controller.
plug AshMultiAccount.Phoenix.Plug